import { Server } from "socket.io";
import {TSocket} from "../../../utilities/Types";
import path from "path";
import fs from "fs";
import ObjectRepository from '../../../repositories/ObjectRepository'

interface IPayload {
    object: string;
}

/**
 * Handle game master remove object event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:object:remove', async (data: IPayload, callback: (response: boolean) => void) => {

        if (socket.character?.role !== 'gm') {
            return;
        }

        try {
            await ObjectRepository.delete(data.object);

            // get root path
            const public_folder = path.join(process.cwd(), 'public', 'objects');

            // remove the tile from the disk
            const finalFilePath = path.join(public_folder, data.object + '.png');
            fs.unlink(finalFilePath, (err) => {
                if (err) {
                    console.log(err);
                    callback(false);
                    return;
                }

                callback(true);
            });
        } catch (e) {
            console.log(e);
            callback(false);
        }
    });
}